import { Module } from "@nestjs/common";

import { ConfigModule } from "@nestjs/config";
import { ThrottlerModule } from "@nestjs/throttler";
import { AuthorsModule } from "apps/backend/src/app/authors/authors.module";
import { AdminModule } from "./admin/admin.module";
import { AppController } from "./app.controller";
import { AppService } from "./app.service";
import { AuthModule } from "./auth/auth.module";
import { CredentialsModule } from "./credentials/credentials.module";
import { DbModule } from "./db/db.module";
import { FilesModule } from "./files/files.module";
import { GroupsModule } from "./groups/groups.module";
import { MachinesModule } from "./machines/machines.module";

@Module({
	imports: [
		ThrottlerModule.forRoot([
			{
				ttl: 60000,
				limit: 10,
			},
		]),
		ConfigModule.forRoot({
			isGlobal: true,
		}),
		DbModule,
		AuthModule,
		CredentialsModule,
		FilesModule,
		AdminModule,
		GroupsModule,
		MachinesModule,
		AuthorsModule,
	],
	controllers: [AppController],
	providers: [AppService],
})
export class AppModule {}
